@@ -39,7 +39,8 @@ list.sort.functions <- list(desc=`-`)
 
 setnames <- `names<-`
 
-getnames <- function(x,null=NULL) if(is.null(names(x))) null else names(x)
+getnames <- function(x, null = NULL)
+  if(is.null(names(x))) null else names(x)
 
 set_argnames <- function(args,data=args) {
   argnames <- names(args)
@@ -50,3 +51,5 @@ set_argnames <- function(args,data=args) {
 }
 
 setmembers <- `[<-`
+
+is.null.or.empty <- function(x) is.null(x) || length(x) == 0L
