@@ -1,7 +1,7 @@
 #' Sort a list by given expressions in order
 #'
 #' @param .data \code{list}
-#' @param ... Expressions to evaluate for sorting
+#' @param ... A group of lambda expressions
 #' @name list.sort
 #' @export
 #' @examples
@@ -13,6 +13,5 @@
 #' list.sort(x,min(score$c1,score$c2))
 #' }
 list.sort <- function(.data,...) {
-  args <- as.list(match.call(expand.dots = FALSE))$`...`
-  .data[list.order.internal(.data,args)]
+  .data[list.order.internal(.data,dots(...))]
 }
