@@ -36,3 +36,20 @@ students %>>%
   list.ungroup %>>%
   list.stack
 
+## ------------------------------------------------------------------------
+is.prime <- function(num) {
+   if (num == 2L) {
+      TRUE
+   } else if (any(num %% 2L:(num-1L) == 0L)) {
+      FALSE
+   } else { 
+      TRUE
+   }
+}
+
+## ------------------------------------------------------------------------
+list.find(1:1000,is.prime(.),50)
+
+## ------------------------------------------------------------------------
+list.filter(1:500,is.prime(.))
+
